# Animations

## flyvis.analysis.animations.imshow

### Classes

::: flyvis.analysis.animations.imshow.Imshow
    options:
      heading_level: 4

## flyvis.analysis.animations.hexscatter
### Classes

::: flyvis.analysis.animations.hexscatter.HexScatter
    options:
      heading_level: 4

## flyvis.analysis.animations.hexflow

### Classes

::: flyvis.analysis.animations.hexflow.HexFlow
    options:
      heading_level: 4

## flyvis.analysis.animations.sintel

### Classes

::: flyvis.analysis.animations.sintel.SintelSample
    options:
      heading_level: 4

## flyvis.analysis.animations.activations

### Classes

::: flyvis.analysis.animations.activations.StimulusResponse
    options:
      heading_level: 4

## flyvis.analysis.animations.network

### Classes

::: flyvis.analysis.animations.network.WholeNetworkAnimation
    options:
      heading_level: 4


## flyvis.analysis.animations.animations

### Classes

::: flyvis.analysis.animations.animations.Animation
    options:
      heading_level: 4

::: flyvis.analysis.animations.animations.AnimationCollector
    options:
      heading_level: 4

### Functions

::: flyvis.analysis.animations.animations.convert
    options:
      heading_level: 4







## flyvis.analysis.animations.traces

### Classes

::: flyvis.analysis.animations.traces.Trace
    options:
      heading_level: 4

::: flyvis.analysis.animations.traces.MultiTrace
    options:
      heading_level: 4
